@@ -2,7 +2,9 @@
 #define R2_REG_H
 
 #include <r_types.h>
-#include <r_util.h>
+#include <r_list.h>
+#include <r_util/r_hex.h>
+#include <r_util/r_assert.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -48,7 +50,7 @@ typedef enum {
 	R_REG_NAME_A8,
 	R_REG_NAME_A9,
 	/* retval */
-	R_REG_NAME_R0, // arguments
+	R_REG_NAME_R0, // return registers
 	R_REG_NAME_R1,
 	R_REG_NAME_R2,
 	R_REG_NAME_R3,
